import { defineComponent, openBlock, createElementBlock, withModifiers, createElementVNode, normalizeStyle } from "vue";
import { createLinearGradient } from "./composible.js";
import "./Saturation.vue_vue_type_style_index_0_lang.js";
import _export_sfc from "../../_virtual/plugin-vue_export-helper.js";
const _sfc_main = defineComponent({
  props: {
    color: {
      type: String,
      default: "#000000"
    },
    hsv: {
      type: Object,
      default: null
    },
    size: {
      type: Number,
      default: 152
    }
  },
  emits: ["selectSaturation"],
  data() {
    return {
      slideSaturationStyle: {}
    };
  },
  mounted() {
    this.renderColor();
    this.renderSlide();
  },
  methods: {
    renderColor() {
      const canvas = this.$refs.canvasSaturation;
      const { size } = this;
      const ctx = canvas.getContext("2d");
      canvas.width = size;
      canvas.height = size;
      ctx.fillStyle = this.color;
      ctx.fillRect(0, 0, size, size);
      createLinearGradient(
        "l",
        ctx,
        size,
        size,
        "#FFFFFF",
        "rgba(255,255,255,0)"
      );
      createLinearGradient("p", ctx, size, size, "rgba(0,0,0,0)", "#000000");
    },
    renderSlide() {
      this.slideSaturationStyle = {
        left: `${this.hsv.s * this.size - 5}px`,
        top: `${(1 - this.hsv.v) * this.size - 5}px`
      };
    },
    selectSaturation(e) {
      const { top: saturationTop, left: saturationLeft } = this.$el.getBoundingClientRect();
      const ctx = e.target.getContext("2d");
      const mousemove = (e2) => {
        let x = e2.clientX - saturationLeft;
        let y = e2.clientY - saturationTop;
        if (x < 0) {
          x = 0;
        }
        if (y < 0) {
          y = 0;
        }
        if (x > this.size) {
          x = this.size;
        }
        if (y > this.size) {
          y = this.size;
        }
        this.slideSaturationStyle = {
          left: `${x - 5}px`,
          top: `${y - 5}px`
        };
        const imgData = ctx.getImageData(
          Math.min(x, this.size - 1),
          Math.min(y, this.size - 1),
          1,
          1
        );
        const [r, g, b] = imgData.data;
        this.$emit("selectSaturation", { r, g, b });
      };
      mousemove(e);
      const mouseup = () => {
        document.removeEventListener("mousemove", mousemove);
        document.removeEventListener("mouseup", mouseup);
      };
      document.addEventListener("mousemove", mousemove);
      document.addEventListener("mouseup", mouseup);
    }
  }
});
const _hoisted_1 = { ref: "canvasSaturation" };
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", {
    class: "saturation",
    onMousedown: _cache[0] || (_cache[0] = withModifiers((...args) => _ctx.selectSaturation && _ctx.selectSaturation(...args), ["prevent", "stop"]))
  }, [
    createElementVNode("canvas", _hoisted_1, null, 512),
    createElementVNode("div", {
      style: normalizeStyle(_ctx.slideSaturationStyle),
      class: "slide"
    }, null, 4)
  ], 32);
}
var Saturation = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
export { Saturation as default };
