import { defineComponent, toRefs, ref, computed, resolveComponent, openBlock, createElementBlock, normalizeClass, createVNode, withCtx, createElementVNode, normalizeStyle, createBlock, renderSlot } from "vue";
import { getPrefixCls } from "../_utils/global-config.js";
import { isUndefined, isNull } from "../_utils/is.js";
import ColorKit from "./color/ColorKit.js";
import Trigger from "../trigger/index.js";
import Input from "../input/index.js";
import IconStop from "../icon/icon-stop/index.js";
import IconDown from "../icon/icon-down/index.js";
import _export_sfc from "../_virtual/plugin-vue_export-helper.js";
const _sfc_main = defineComponent({
  name: "ColorPicker",
  components: {
    ColorKit,
    Trigger,
    Input,
    IconStop,
    IconDown
  },
  props: {
    input: {
      type: Boolean,
      default: false
    },
    custom: {
      type: Boolean,
      default: false
    },
    disabled: {
      type: Boolean,
      default: false
    },
    modelValue: String
  },
  emits: {
    "update:modelValue": (value) => true,
    "change": (value) => true
  },
  setup(props, { emit }) {
    const { modelValue } = toRefs(props);
    const color = ref(modelValue.value || "#307af2");
    const changeColor = ({ hex, hsv, rgba }) => {
      const { r, g, b, a } = rgba;
      if (a === 1) {
        updateValue(hex);
      } else {
        updateValue(`rgba(${r}, ${g}, ${b}, ${a})`);
      }
    };
    const updateValue = (value) => {
      if (isUndefined(value) || isNull(value)) {
        color.value = "";
      }
      color.value = value;
      emit("update:modelValue", value);
      emit("change", value);
    };
    const prefixCls = getPrefixCls("color-picker");
    const cls = computed(() => [
      prefixCls,
      {
        [`${prefixCls}-input`]: props.input,
        [`${prefixCls}-disabled`]: props.disabled
      }
    ]);
    const theme = ref("dark");
    const onPopChange = () => {
      theme.value = document.body.getAttribute("mo-theme") === "dark" ? "dark" : "light";
    };
    const colorHex3To6 = (digit) => {
      let _digit = digit;
      _digit = _digit.split("").map((item) => {
        if (item === "#")
          return item;
        return item + item;
      }).join("");
      if (_digit[0] !== "#") {
        _digit = `#${_digit}`;
      }
      return _digit;
    };
    const onInputChange = (value) => {
      if (value.replace("#", "").length === 3)
        color.value = colorHex3To6(value);
    };
    return {
      cls,
      prefixCls,
      changeColor,
      updateValue,
      color,
      theme,
      onPopChange,
      onInputChange
    };
  }
});
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_icon_stop = resolveComponent("icon-stop");
  const _component_icon_down = resolveComponent("icon-down");
  const _component_ColorKit = resolveComponent("ColorKit");
  const _component_Trigger = resolveComponent("Trigger");
  const _component_Input = resolveComponent("Input");
  const _component_trigger = resolveComponent("trigger");
  return openBlock(), createElementBlock("div", {
    class: normalizeClass(_ctx.cls)
  }, [
    _ctx.input ? (openBlock(), createElementBlock("span", {
      key: 0,
      class: normalizeClass(`${_ctx.prefixCls}-input-box`)
    }, [
      createVNode(_component_Input, {
        modelValue: _ctx.color,
        "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => _ctx.color = $event),
        placeholder: "\u8BF7\u8F93\u5165\u989C\u8272\u503C",
        disabled: _ctx.disabled,
        onInput: _ctx.updateValue,
        onChange: _ctx.onInputChange
      }, {
        suffix: withCtx(() => [
          createVNode(_component_Trigger, {
            disabled: _ctx.disabled,
            trigger: ["click"],
            position: "rt",
            "popup-translate": [10, 0],
            "click-outside-to-close": true,
            onPopupVisibleChange: _ctx.onPopChange
          }, {
            content: withCtx(() => [
              createVNode(_component_ColorKit, {
                theme: _ctx.theme,
                color: _ctx.color,
                onChangeColor: _ctx.changeColor
              }, null, 8, ["theme", "color", "onChangeColor"])
            ]),
            default: withCtx(() => [
              createElementVNode("span", {
                class: normalizeClass(`${_ctx.prefixCls}-color`)
              }, [
                createElementVNode("span", {
                  class: normalizeClass(`${_ctx.prefixCls}-alpha`)
                }, [
                  createElementVNode("span", {
                    class: normalizeClass(`${_ctx.prefixCls}-value`),
                    style: normalizeStyle({ "background-color": _ctx.color })
                  }, null, 6)
                ], 2),
                createElementVNode("span", {
                  class: normalizeClass(`${_ctx.prefixCls}-icon`)
                }, [
                  _ctx.disabled ? (openBlock(), createBlock(_component_icon_stop, { key: 0 })) : (openBlock(), createBlock(_component_icon_down, { key: 1 }))
                ], 2)
              ], 2)
            ]),
            _: 1
          }, 8, ["disabled", "onPopupVisibleChange"])
        ]),
        _: 1
      }, 8, ["modelValue", "disabled", "onInput", "onChange"])
    ], 2)) : (openBlock(), createBlock(_component_trigger, {
      key: 1,
      disabled: _ctx.disabled,
      trigger: ["click"],
      position: "rt",
      "popup-translate": [10, 0],
      "click-outside-to-close": true,
      onPopupVisibleChange: _ctx.onPopChange
    }, {
      content: withCtx(() => [
        createVNode(_component_ColorKit, {
          theme: _ctx.theme,
          color: _ctx.color,
          onChangeColor: _ctx.changeColor
        }, null, 8, ["theme", "color", "onChangeColor"])
      ]),
      default: withCtx(() => [
        _ctx.custom ? renderSlot(_ctx.$slots, "default", { key: 0 }) : (openBlock(), createElementBlock("span", {
          key: 1,
          class: normalizeClass(`${_ctx.prefixCls}-color`)
        }, [
          createElementVNode("span", {
            class: normalizeClass(`${_ctx.prefixCls}-alpha`)
          }, [
            createElementVNode("span", {
              class: normalizeClass(`${_ctx.prefixCls}-value`),
              style: normalizeStyle({ "background-color": _ctx.color })
            }, null, 6)
          ], 2),
          createElementVNode("span", {
            class: normalizeClass(`${_ctx.prefixCls}-icon`)
          }, [
            _ctx.disabled ? (openBlock(), createBlock(_component_icon_stop, { key: 0 })) : (openBlock(), createBlock(_component_icon_down, { key: 1 }))
          ], 2)
        ], 2))
      ]),
      _: 3
    }, 8, ["disabled", "onPopupVisibleChange"]))
  ], 2);
}
var _ColorPicker = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
export { _ColorPicker as default };
