import { defineComponent, ref, onMounted, openBlock, createElementBlock, createElementVNode, normalizeStyle } from "vue";
import QRCode from "qrcode";
import { QRCODE_TYPES } from "./constants.js";
import _export_sfc from "../_virtual/plugin-vue_export-helper.js";
const _sfc_main = defineComponent({
  name: "Qrcode",
  components: {},
  props: {
    type: {
      type: String,
      default: QRCODE_TYPES[0],
      validator: (value) => {
        return QRCODE_TYPES.includes(value);
      }
    },
    text: {
      type: String,
      required: true
    },
    width: {
      type: Number
    },
    dark: {
      type: String
    },
    light: {
      type: String
    }
  },
  emits: {
    getUrl: (url) => true
  },
  setup(props, { emit }) {
    const ID = Math.random().toString(36).substr(2);
    const DATA_URL = ref("");
    const init = () => {
      const OPTION = {
        margin: 0,
        width: Number(props.width),
        color: {
          dark: props.dark,
          light: props.light
        }
      };
      if (props.type === "canvas") {
        QRCode.toCanvas(
          props.text,
          OPTION,
          (err, canvas) => {
            if (err)
              throw err;
            const container = document.getElementById(ID);
            if (!container)
              return;
            container && container.appendChild(canvas);
            emit("getUrl", canvas);
          }
        );
      } else if (props.type === "image") {
        QRCode.toDataURL(props.text, OPTION, (err, url) => {
          if (err)
            throw err;
          const image = document.getElementById(ID);
          if (!image)
            return;
          image.src = url;
          DATA_URL.value = url;
          emit("getUrl", DATA_URL.value);
        });
      }
    };
    onMounted(() => init());
    return {
      ID
    };
  }
});
const _hoisted_1 = ["id"];
const _hoisted_2 = {
  key: 1,
  class: "qrcode qrcode-image"
};
const _hoisted_3 = ["id"];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return _ctx.type === "canvas" ? (openBlock(), createElementBlock("div", {
    key: 0,
    id: _ctx.ID,
    class: "qrcode qrcode-canvas"
  }, null, 8, _hoisted_1)) : (openBlock(), createElementBlock("div", _hoisted_2, [
    createElementVNode("img", {
      id: _ctx.ID,
      style: normalizeStyle({ width: `${_ctx.width}px`, height: `${_ctx.width}px` })
    }, null, 12, _hoisted_3)
  ]));
}
var _Qrcode = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
export { _Qrcode as default };
