import { defineComponent, inject, computed, resolveComponent, openBlock, createElementBlock, mergeProps, createElementVNode, normalizeClass, renderSlot, createCommentVNode, createBlock, withModifiers, withCtx, createVNode } from "vue";
import { getPrefixCls } from "../_utils/global-config.js";
import IconHover from "../_components/icon-hover.js";
import IconClose from "../icon/icon-close/index.js";
import { tabsInjectionKey } from "./context.js";
import _export_sfc from "../_virtual/plugin-vue_export-helper.js";
const _sfc_main = defineComponent({
  name: "TabsTab",
  components: {
    IconHover,
    IconClose
  },
  props: {
    tab: {
      type: Object,
      required: true
    },
    active: Boolean,
    editable: Boolean
  },
  emits: ["click", "delete"],
  setup(props, { emit }) {
    const prefixCls = getPrefixCls("tabs-tab");
    const tabsCtx = inject(tabsInjectionKey, {});
    const handleClick = (e) => {
      if (!props.tab.disabled) {
        emit("click", props.tab.key, e);
      }
    };
    const onKeyDown = (ev) => {
      if (ev.key === "Enter") {
        handleClick(ev);
      }
    };
    const eventHandlers = computed(() => {
      return Object.assign(
        tabsCtx.trigger === "click" ? { onClick: handleClick } : { onMouseover: handleClick },
        { onKeydown: onKeyDown }
      );
    });
    const handleDelete = (e) => {
      if (!props.tab.disabled) {
        emit("delete", props.tab.key, e);
      }
    };
    const cls = computed(() => [
      prefixCls,
      {
        [`${prefixCls}-active`]: props.active,
        [`${prefixCls}-closable`]: props.editable && props.tab.closable,
        [`${prefixCls}-disabled`]: props.tab.disabled
      }
    ]);
    return {
      prefixCls,
      cls,
      eventHandlers,
      handleDelete
    };
  }
});
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_icon_close = resolveComponent("icon-close");
  const _component_icon_hover = resolveComponent("icon-hover");
  return openBlock(), createElementBlock("div", mergeProps({
    tabindex: "0",
    class: _ctx.cls
  }, _ctx.eventHandlers), [
    createElementVNode("span", {
      class: normalizeClass(`${_ctx.prefixCls}-title`)
    }, [
      renderSlot(_ctx.$slots, "default")
    ], 2),
    _ctx.$attrs.type === "graph" ? (openBlock(), createElementBlock("div", {
      key: 0,
      class: normalizeClass(`${_ctx.prefixCls}-card-bg`)
    }, [
      Number(_ctx.$attrs.tabIndex) === 0 && _ctx.active ? (openBlock(), createElementBlock("svg", {
        key: 0,
        class: normalizeClass(`${_ctx.prefixCls}-bg-icon`),
        width: "184px",
        height: "56px",
        viewBox: "0 0 152 48",
        version: "1.1",
        preserveAspectRatio: "none meet",
        xmlns: "http://www.w3.org/2000/svg",
        "xmlns:xlink": "http://www.w3.org/1999/xlink"
      }, _cache[0] || (_cache[0] = [
        createElementVNode("g", {
          id: "background-tabs",
          stroke: "none",
          "stroke-width": "1",
          fill: "none",
          "fill-rule": "evenodd"
        }, [
          createElementVNode("g", {
            id: "background-items",
            fill: "#FFFFFF"
          }, [
            createElementVNode("path", {
              id: "\u77E9\u5F62",
              d: "M8,0 L114.396582,0 C117.760633,2.93474744e-15 120.765288,2.104542 121.914929,5.2660555 L130.363829,28.5005298 C133.887865,38.1916279 141.995944,45.498986 152,48 L152,48 L152,48 L0,48 L0,8 C-5.41083001e-16,3.581722 3.581722,-1.85291076e-15 8,0 Z"
            })
          ])
        ], -1)
      ]), 2)) : createCommentVNode("v-if", true),
      Number(_ctx.$attrs.tabIndex) !== 0 && _ctx.active ? (openBlock(), createElementBlock("svg", {
        key: 1,
        class: normalizeClass(`${_ctx.prefixCls}-bg-icon`),
        width: "216px",
        height: "56px",
        viewBox: "0 0 184 48",
        version: "1.1",
        preserveAspectRatio: "none meet",
        xmlns: "http://www.w3.org/2000/svg",
        "xmlns:xlink": "http://www.w3.org/1999/xlink"
      }, _cache[1] || (_cache[1] = [
        createElementVNode("g", {
          id: "background-tabs",
          stroke: "none",
          "stroke-width": "1",
          fill: "none",
          "fill-rule": "evenodd"
        }, [
          createElementVNode("g", {
            id: "background-items",
            fill: "#FFFFFF"
          }, [
            createElementVNode("path", {
              id: "\u77E9\u5F62",
              d: "M37.6034181,0 L146.396582,0 C149.760633,8.26381796e-15 152.765288,2.104542 153.914929,5.2660555 L162.363829,28.5005298 C165.887865,38.1916279 173.995944,45.498986 184,48 L184,48 L184,48 L0,48 C10.0040561,45.498986 18.1121353,38.1916279 21.636171,28.5005298 L30.0850707,5.2660555 C31.234712,2.104542 34.2393666,-2.04656902e-15 37.6034181,0 Z"
            })
          ])
        ], -1)
      ]), 2)) : createCommentVNode("v-if", true)
    ], 2)) : createCommentVNode("v-if", true),
    _ctx.editable && _ctx.tab.closable ? (openBlock(), createBlock(_component_icon_hover, {
      key: 1,
      class: normalizeClass(`${_ctx.prefixCls}-close-btn`),
      onClick: withModifiers(_ctx.handleDelete, ["stop"])
    }, {
      default: withCtx(() => [
        createVNode(_component_icon_close)
      ]),
      _: 1
    }, 8, ["class", "onClick"])) : createCommentVNode("v-if", true)
  ], 16);
}
var TabsTab = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
export { TabsTab as default };
