"use strict";
var vue = require("vue");
var globalConfig = require("../_utils/global-config.js");
var is = require("../_utils/is.js");
var ColorKit = require("./color/ColorKit.js");
var index = require("../trigger/index.js");
var index$1 = require("../input/index.js");
var index$2 = require("../icon/icon-stop/index.js");
var index$3 = require("../icon/icon-down/index.js");
var pluginVue_exportHelper = require("../_virtual/plugin-vue_export-helper.js");
const _sfc_main = vue.defineComponent({
  name: "ColorPicker",
  components: {
    ColorKit,
    Trigger: index,
    Input: index$1["default"],
    IconStop: index$2,
    IconDown: index$3
  },
  props: {
    input: {
      type: Boolean,
      default: false
    },
    custom: {
      type: Boolean,
      default: false
    },
    disabled: {
      type: Boolean,
      default: false
    },
    modelValue: String
  },
  emits: {
    "update:modelValue": (value) => true,
    "change": (value) => true
  },
  setup(props, { emit }) {
    const { modelValue } = vue.toRefs(props);
    const color = vue.ref(modelValue.value || "#307af2");
    const changeColor = ({ hex, hsv, rgba }) => {
      const { r, g, b, a } = rgba;
      if (a === 1) {
        updateValue(hex);
      } else {
        updateValue(`rgba(${r}, ${g}, ${b}, ${a})`);
      }
    };
    const updateValue = (value) => {
      if (is.isUndefined(value) || is.isNull(value)) {
        color.value = "";
      }
      color.value = value;
      emit("update:modelValue", value);
      emit("change", value);
    };
    const prefixCls = globalConfig.getPrefixCls("color-picker");
    const cls = vue.computed(() => [
      prefixCls,
      {
        [`${prefixCls}-input`]: props.input,
        [`${prefixCls}-disabled`]: props.disabled
      }
    ]);
    const theme = vue.ref("dark");
    const onPopChange = () => {
      theme.value = document.body.getAttribute("mo-theme") === "dark" ? "dark" : "light";
    };
    const colorHex3To6 = (digit) => {
      let _digit = digit;
      _digit = _digit.split("").map((item) => {
        if (item === "#")
          return item;
        return item + item;
      }).join("");
      if (_digit[0] !== "#") {
        _digit = `#${_digit}`;
      }
      return _digit;
    };
    const onInputChange = (value) => {
      if (value.replace("#", "").length === 3)
        color.value = colorHex3To6(value);
    };
    return {
      cls,
      prefixCls,
      changeColor,
      updateValue,
      color,
      theme,
      onPopChange,
      onInputChange
    };
  }
});
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_icon_stop = vue.resolveComponent("icon-stop");
  const _component_icon_down = vue.resolveComponent("icon-down");
  const _component_ColorKit = vue.resolveComponent("ColorKit");
  const _component_Trigger = vue.resolveComponent("Trigger");
  const _component_Input = vue.resolveComponent("Input");
  const _component_trigger = vue.resolveComponent("trigger");
  return vue.openBlock(), vue.createElementBlock("div", {
    class: vue.normalizeClass(_ctx.cls)
  }, [
    _ctx.input ? (vue.openBlock(), vue.createElementBlock("span", {
      key: 0,
      class: vue.normalizeClass(`${_ctx.prefixCls}-input-box`)
    }, [
      vue.createVNode(_component_Input, {
        modelValue: _ctx.color,
        "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => _ctx.color = $event),
        placeholder: "\u8BF7\u8F93\u5165\u989C\u8272\u503C",
        disabled: _ctx.disabled,
        onInput: _ctx.updateValue,
        onChange: _ctx.onInputChange
      }, {
        suffix: vue.withCtx(() => [
          vue.createVNode(_component_Trigger, {
            disabled: _ctx.disabled,
            trigger: ["click"],
            position: "rt",
            "popup-translate": [10, 0],
            "click-outside-to-close": true,
            onPopupVisibleChange: _ctx.onPopChange
          }, {
            content: vue.withCtx(() => [
              vue.createVNode(_component_ColorKit, {
                theme: _ctx.theme,
                color: _ctx.color,
                onChangeColor: _ctx.changeColor
              }, null, 8, ["theme", "color", "onChangeColor"])
            ]),
            default: vue.withCtx(() => [
              vue.createElementVNode("span", {
                class: vue.normalizeClass(`${_ctx.prefixCls}-color`)
              }, [
                vue.createElementVNode("span", {
                  class: vue.normalizeClass(`${_ctx.prefixCls}-alpha`)
                }, [
                  vue.createElementVNode("span", {
                    class: vue.normalizeClass(`${_ctx.prefixCls}-value`),
                    style: vue.normalizeStyle({ "background-color": _ctx.color })
                  }, null, 6)
                ], 2),
                vue.createElementVNode("span", {
                  class: vue.normalizeClass(`${_ctx.prefixCls}-icon`)
                }, [
                  _ctx.disabled ? (vue.openBlock(), vue.createBlock(_component_icon_stop, { key: 0 })) : (vue.openBlock(), vue.createBlock(_component_icon_down, { key: 1 }))
                ], 2)
              ], 2)
            ]),
            _: 1
          }, 8, ["disabled", "onPopupVisibleChange"])
        ]),
        _: 1
      }, 8, ["modelValue", "disabled", "onInput", "onChange"])
    ], 2)) : (vue.openBlock(), vue.createBlock(_component_trigger, {
      key: 1,
      disabled: _ctx.disabled,
      trigger: ["click"],
      position: "rt",
      "popup-translate": [10, 0],
      "click-outside-to-close": true,
      onPopupVisibleChange: _ctx.onPopChange
    }, {
      content: vue.withCtx(() => [
        vue.createVNode(_component_ColorKit, {
          theme: _ctx.theme,
          color: _ctx.color,
          onChangeColor: _ctx.changeColor
        }, null, 8, ["theme", "color", "onChangeColor"])
      ]),
      default: vue.withCtx(() => [
        _ctx.custom ? vue.renderSlot(_ctx.$slots, "default", { key: 0 }) : (vue.openBlock(), vue.createElementBlock("span", {
          key: 1,
          class: vue.normalizeClass(`${_ctx.prefixCls}-color`)
        }, [
          vue.createElementVNode("span", {
            class: vue.normalizeClass(`${_ctx.prefixCls}-alpha`)
          }, [
            vue.createElementVNode("span", {
              class: vue.normalizeClass(`${_ctx.prefixCls}-value`),
              style: vue.normalizeStyle({ "background-color": _ctx.color })
            }, null, 6)
          ], 2),
          vue.createElementVNode("span", {
            class: vue.normalizeClass(`${_ctx.prefixCls}-icon`)
          }, [
            _ctx.disabled ? (vue.openBlock(), vue.createBlock(_component_icon_stop, { key: 0 })) : (vue.openBlock(), vue.createBlock(_component_icon_down, { key: 1 }))
          ], 2)
        ], 2))
      ]),
      _: 3
    }, 8, ["disabled", "onPopupVisibleChange"]))
  ], 2);
}
var _ColorPicker = /* @__PURE__ */ pluginVue_exportHelper(_sfc_main, [["render", _sfc_render]]);
module.exports = _ColorPicker;
