"use strict";
var vue = require("vue");
var globalConfig = require("../_utils/global-config.js");
var useTreeContext = require("./hooks/use-tree-context.js");
var nodeSwitcher_vue_vue_type_script_lang = require("./node-switcher.vue_vue_type_script_lang.js");
var useNodeKey = require("./hooks/use-node-key.js");
var index = require("../checkbox/index.js");
var renderFunction = require("../_components/render-function.js");
var is = require("../_utils/is.js");
var useDraggable = require("./hooks/use-draggable.js");
var index$1 = require("../icon/icon-drag-dot-vertical/index.js");
var toArray = require("../_utils/to-array.js");
var pluginVue_exportHelper = require("../_virtual/plugin-vue_export-helper.js");
const _sfc_main = vue.defineComponent({
  name: "BaseTreeNode",
  components: {
    NodeSwitcher: nodeSwitcher_vue_vue_type_script_lang,
    Checkbox: index["default"],
    RenderFunction: renderFunction,
    IconDragDotVertical: index$1
  },
  props: {
    key: {
      type: [String, Number]
    },
    title: {
      type: String
    },
    selectable: {
      type: Boolean
    },
    disabled: {
      type: Boolean
    },
    disableCheckbox: {
      type: Boolean
    },
    checkable: {
      type: Boolean
    },
    draggable: {
      type: Boolean
    },
    isLeaf: {
      type: Boolean
    },
    icon: {
      type: Function
    },
    switcherIcon: {
      type: Function
    },
    loadingIcon: {
      type: Function
    },
    dragIcon: {
      type: Function
    },
    isTail: {
      type: Boolean
    },
    blockNode: {
      type: Boolean
    },
    showLine: {
      type: Boolean
    },
    level: {
      type: Number,
      default: 0
    },
    lineless: {
      type: Array,
      default: () => []
    }
  },
  emits: ["onNodeRmove", "onTitleChange", "onNodeAppend"],
  setup(props, { emit }) {
    const key = useNodeKey();
    const prefixCls = globalConfig.getPrefixCls("tree-node");
    const iconPrefixCls = globalConfig.getPrefixCls("icon");
    const treeContext = useTreeContext();
    const node = vue.computed(
      () => {
        var _a;
        return (_a = treeContext.key2TreeNode) == null ? void 0 : _a.get(key.value);
      }
    );
    const treeNodeData = vue.computed(() => node.value.treeNodeData);
    const children = vue.computed(() => node.value.children);
    const actionOnNodeClick = vue.computed(() => {
      var _a;
      const action = (_a = treeContext.treeProps) == null ? void 0 : _a.actionOnNodeClick;
      return action ? toArray.toArray(action) : [];
    });
    const isRoot = vue.computed(() => is.isUndefined(node.value.parentKey));
    const isEdit = vue.ref(false);
    const { isLeaf, isTail, selectable, disabled, disableCheckbox, draggable } = vue.toRefs(props);
    const classNames = vue.computed(() => {
      var _a;
      return [
        `${prefixCls}`,
        {
          [`${prefixCls}-selected`]: selected.value,
          [`${prefixCls}-is-leaf`]: isLeaf.value,
          [`${prefixCls}-is-tail`]: isTail.value,
          [`${prefixCls}-expanded`]: expanded.value,
          [`${prefixCls}-disabled-selectable`]: !selectable.value && !((_a = treeContext.treeProps) == null ? void 0 : _a.disableSelectActionOnly),
          [`${prefixCls}-disabled`]: disabled.value
        }
      ];
    });
    const refTitle = vue.ref();
    const { isDragOver, isDragging, isAllowDrop, dropPosition, setDragStatus } = useDraggable(
      vue.reactive({
        key,
        refTitle
      })
    );
    const titleClassNames = vue.computed(() => [
      `${prefixCls}-title`,
      {
        [`${prefixCls}-title-draggable`]: draggable.value,
        [`${prefixCls}-title-gap-top`]: isDragOver.value && isAllowDrop.value && dropPosition.value < 0,
        [`${prefixCls}-title-gap-bottom`]: isDragOver.value && isAllowDrop.value && dropPosition.value > 0,
        [`${prefixCls}-title-highlight`]: !isDragging.value && isDragOver.value && isAllowDrop.value && dropPosition.value === 0,
        [`${prefixCls}-title-dragging`]: isDragging.value,
        [`${prefixCls}-title-block`]: node.value.blockNode,
        [`${prefixCls}-nohover`]: isEdit.value
      }
    ]);
    const append = vue.computed(() => {
      var _a;
      return (_a = treeContext.treeProps) == null ? void 0 : _a.append;
    });
    const edit = vue.computed(() => {
      var _a;
      return (_a = treeContext.treeProps) == null ? void 0 : _a.edit;
    });
    const remove = vue.computed(() => {
      var _a;
      return (_a = treeContext.treeProps) == null ? void 0 : _a.remove;
    });
    const removeConfirm = vue.computed(() => {
      var _a;
      return (_a = treeContext.treeProps) == null ? void 0 : _a.removeConfirm;
    });
    const checked = vue.computed(
      () => {
        var _a, _b;
        return (_b = (_a = treeContext.checkedKeys) == null ? void 0 : _a.includes) == null ? void 0 : _b.call(_a, key.value);
      }
    );
    const indeterminate = vue.computed(
      () => {
        var _a, _b;
        return (_b = (_a = treeContext.indeterminateKeys) == null ? void 0 : _a.includes) == null ? void 0 : _b.call(_a, key.value);
      }
    );
    const selected = vue.computed(
      () => {
        var _a, _b;
        return (_b = (_a = treeContext.selectedKeys) == null ? void 0 : _a.includes) == null ? void 0 : _b.call(_a, key.value);
      }
    );
    const expanded = vue.computed(
      () => {
        var _a, _b;
        return (_b = (_a = treeContext.expandedKeys) == null ? void 0 : _a.includes) == null ? void 0 : _b.call(_a, key.value);
      }
    );
    const loading = vue.computed(
      () => {
        var _a, _b;
        return (_b = (_a = treeContext.loadingKeys) == null ? void 0 : _a.includes) == null ? void 0 : _b.call(_a, key.value);
      }
    );
    const treeDragIcon = vue.computed(() => treeContext.dragIcon);
    const treeNodeIcon = vue.computed(() => treeContext.nodeIcon);
    function onSwitcherClick(e) {
      var _a, _b;
      if (isLeaf.value)
        return;
      if (!((_a = children.value) == null ? void 0 : _a.length) && is.isFunction(treeContext.onLoadMore)) {
        treeContext.onLoadMore(key.value);
      } else {
        (_b = treeContext == null ? void 0 : treeContext.onExpand) == null ? void 0 : _b.call(treeContext, !expanded.value, key.value, e);
      }
    }
    const nodeStatus = vue.reactive({
      loading,
      checked,
      selected,
      indeterminate,
      expanded,
      isLeaf
    });
    const treeTitle = vue.computed(
      () => treeContext.nodeTitle ? () => {
        var _a;
        return (_a = treeContext.nodeTitle) == null ? void 0 : _a.call(treeContext, treeNodeData.value, nodeStatus);
      } : void 0
    );
    const extra = vue.computed(
      () => treeContext.nodeExtra ? () => {
        var _a;
        return (_a = treeContext.nodeExtra) == null ? void 0 : _a.call(treeContext, treeNodeData.value, nodeStatus);
      } : void 0
    );
    const onAppend = () => {
      const nodeData = treeNodeData.value;
      const children2 = nodeData.children || [];
      children2.push({
        title: "\u65B0\u589E\u7684\u8282\u70B9",
        key: `${nodeData.key}-${children2.length + 1}`
      });
      nodeData.children = children2;
      emit("onNodeAppend");
    };
    const confirmVisible = vue.ref(false);
    const onRemoveConfirm = () => {
      if (removeConfirm.value) {
        confirmVisible.value = true;
      } else {
        onRemove();
      }
      confirmVisible.value = true;
    };
    const onConfirmVisibleChange = (visible) => {
      if (visible === false)
        confirmVisible.value = false;
    };
    const onRemove = () => {
      const nodeData = treeNodeData.value;
      emit("onNodeRmove", nodeData);
      confirmVisible.value = false;
    };
    const inputRef = vue.ref();
    const toggleEdit = async () => {
      var _a;
      isEdit.value = !isEdit.value;
      if (isEdit.value) {
        isInputError.value = false;
        await vue.nextTick();
        (_a = inputRef.value) == null ? void 0 : _a.focus();
      }
    };
    const openEdit = async () => {
      var _a;
      if (!edit.value || disabled.value)
        return;
      isEdit.value = true;
      await vue.nextTick();
      (_a = inputRef.value) == null ? void 0 : _a.focus();
    };
    const inputValue = vue.ref(null);
    const onInput = (value) => {
      isInputError.value = false;
      inputValue.value = value;
    };
    const onInputFocus = () => {
      if (props.title === "\u65B0\u589E\u7684\u8282\u70B9") {
        inputValue.value = "";
      } else if (inputValue.value === null) {
        inputValue.value = props.title;
      }
    };
    const onInputCancel = () => {
      inputValue.value = null;
      isEdit.value = false;
    };
    const onInputSave = () => {
      var _a;
      if (is.isNullString(inputValue.value)) {
        isInputError.value = true;
        (_a = inputRef.value) == null ? void 0 : _a.focus();
      } else {
        isInputError.value = false;
        isEdit.value = false;
        const nodeData = treeNodeData.value;
        emit("onTitleChange", nodeData, inputValue.value);
      }
    };
    const isInputError = vue.ref(false);
    return {
      isRoot,
      refTitle,
      prefixCls,
      iconPrefixCls,
      classNames,
      titleClassNames,
      indeterminate,
      checked,
      expanded,
      selected,
      treeTitle,
      treeNodeData,
      loading,
      treeDragIcon,
      treeNodeIcon,
      append,
      edit,
      isEdit,
      inputValue,
      inputRef,
      isInputError,
      remove,
      onAppend,
      toggleEdit,
      openEdit,
      onInput,
      onInputFocus,
      onInputCancel,
      onInputSave,
      onRemoveConfirm,
      onRemove,
      confirmVisible,
      onConfirmVisibleChange,
      extra,
      nodeStatus,
      onCheckboxChange(checked2, e) {
        var _a;
        if (disableCheckbox.value || disabled.value) {
          return;
        }
        (_a = treeContext.onCheck) == null ? void 0 : _a.call(treeContext, checked2, key.value, e);
      },
      onTitleClick(e) {
        var _a;
        if (actionOnNodeClick.value.includes("expand")) {
          onSwitcherClick(e);
        }
        if (!selectable.value || disabled.value)
          return;
        (_a = treeContext.onSelect) == null ? void 0 : _a.call(treeContext, key.value, e);
      },
      onSwitcherClick,
      onDragStart(e) {
        var _a;
        if (!draggable.value)
          return;
        e.stopPropagation();
        setDragStatus("dragStart", e);
        try {
          (_a = e.dataTransfer) == null ? void 0 : _a.setData("text/plain", "");
        } catch (error) {
        }
      },
      onDragEnd(e) {
        if (!draggable.value)
          return;
        e.stopPropagation();
        setDragStatus("dragEnd", e);
      },
      onDragOver(e) {
        if (!draggable)
          return;
        e.stopPropagation();
        e.preventDefault();
        setDragStatus("dragOver", e);
      },
      onDragLeave(e) {
        if (!draggable.value)
          return;
        e.stopPropagation();
        setDragStatus("dragLeave", e);
      },
      onDrop(e) {
        if (!draggable.value || !isAllowDrop.value)
          return;
        e.stopPropagation();
        e.preventDefault();
        setDragStatus("drop", e);
      }
    };
  }
});
const _hoisted_1 = ["draggable"];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_NodeSwitcher = vue.resolveComponent("NodeSwitcher");
  const _component_Checkbox = vue.resolveComponent("Checkbox");
  const _component_RenderFunction = vue.resolveComponent("RenderFunction");
  const _component_m_input = vue.resolveComponent("m-input");
  const _component_icon_close = vue.resolveComponent("icon-close");
  const _component_m_button = vue.resolveComponent("m-button");
  const _component_icon_check = vue.resolveComponent("icon-check");
  const _component_m_button_group = vue.resolveComponent("m-button-group");
  const _component_IconDragDotVertical = vue.resolveComponent("IconDragDotVertical");
  const _component_m_popconfirm = vue.resolveComponent("m-popconfirm");
  const _component_IconPlus = vue.resolveComponent("IconPlus");
  const _component_icon_pen = vue.resolveComponent("icon-pen");
  const _component_IconDelete = vue.resolveComponent("IconDelete");
  return vue.openBlock(), vue.createElementBlock("div", {
    class: vue.normalizeClass(_ctx.classNames)
  }, [
    vue.createCommentVNode(" \u7F29\u8FDB "),
    vue.createElementVNode("span", {
      class: vue.normalizeClass(`${_ctx.prefixCls}-indent`)
    }, [
      (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.level, (i) => {
        return vue.openBlock(), vue.createElementBlock("span", {
          key: i,
          class: vue.normalizeClass([
            `${_ctx.prefixCls}-indent-block`,
            {
              [`${_ctx.prefixCls}-indent-block-lineless`]: _ctx.lineless[i - 1]
            }
          ])
        }, null, 2);
      }), 128))
    ], 2),
    vue.createCommentVNode(" switcher "),
    vue.createElementVNode("span", {
      class: vue.normalizeClass([
        `${_ctx.prefixCls}-switcher`,
        {
          [`${_ctx.prefixCls}-switcher-expanded`]: _ctx.expanded
        }
      ])
    }, [
      vue.createVNode(_component_NodeSwitcher, {
        "prefix-cls": _ctx.prefixCls,
        loading: _ctx.loading,
        "show-line": _ctx.showLine,
        "tree-node-data": _ctx.treeNodeData,
        icons: {
          switcherIcon: _ctx.switcherIcon,
          loadingIcon: _ctx.loadingIcon
        },
        "node-status": _ctx.nodeStatus,
        onClick: _ctx.onSwitcherClick
      }, vue.createSlots({ _: 2 }, [
        _ctx.$slots["switcher-icon"] ? {
          name: "switcher-icon",
          fn: vue.withCtx(() => [
            vue.createCommentVNode(" @slot \u5B9A\u5236 switcher \u56FE\u6807\uFF0C\u4F1A\u8986\u76D6 Tree \u7684\u914D\u7F6E "),
            vue.renderSlot(_ctx.$slots, "switcher-icon")
          ]),
          key: "0"
        } : void 0,
        _ctx.$slots["loading-icon"] ? {
          name: "loading-icon",
          fn: vue.withCtx(() => [
            vue.createCommentVNode(" @slot \u5B9A\u5236 loading \u56FE\u6807\uFF0C\u4F1A\u8986\u76D6 Tree \u7684\u914D\u7F6E "),
            vue.renderSlot(_ctx.$slots, "loading-icon")
          ]),
          key: "1"
        } : void 0
      ]), 1032, ["prefix-cls", "loading", "show-line", "tree-node-data", "icons", "node-status", "onClick"])
    ], 2),
    vue.createCommentVNode(" checkbox "),
    _ctx.checkable ? (vue.openBlock(), vue.createBlock(_component_Checkbox, {
      key: 0,
      disabled: _ctx.disableCheckbox || _ctx.disabled,
      "model-value": _ctx.checked,
      indeterminate: _ctx.indeterminate,
      "uninject-group-context": "",
      onChange: _ctx.onCheckboxChange
    }, null, 8, ["disabled", "model-value", "indeterminate", "onChange"])) : vue.createCommentVNode("v-if", true),
    vue.createCommentVNode(" \u5185\u5BB9 "),
    vue.createElementVNode("span", {
      ref: "refTitle",
      class: vue.normalizeClass(_ctx.titleClassNames),
      draggable: _ctx.draggable,
      onDragstart: _cache[2] || (_cache[2] = (...args) => _ctx.onDragStart && _ctx.onDragStart(...args)),
      onDragend: _cache[3] || (_cache[3] = (...args) => _ctx.onDragEnd && _ctx.onDragEnd(...args)),
      onDragover: _cache[4] || (_cache[4] = (...args) => _ctx.onDragOver && _ctx.onDragOver(...args)),
      onDragleave: _cache[5] || (_cache[5] = (...args) => _ctx.onDragLeave && _ctx.onDragLeave(...args)),
      onDrop: _cache[6] || (_cache[6] = (...args) => _ctx.onDrop && _ctx.onDrop(...args)),
      onClick: _cache[7] || (_cache[7] = (...args) => _ctx.onTitleClick && _ctx.onTitleClick(...args))
    }, [
      _ctx.$slots.icon || _ctx.icon || _ctx.treeNodeIcon ? (vue.openBlock(), vue.createElementBlock("span", {
        key: 0,
        class: vue.normalizeClass([`${_ctx.prefixCls}-icon`, `${_ctx.prefixCls}-custom-icon`])
      }, [
        vue.createCommentVNode(" \u8282\u70B9\u56FE\u6807 "),
        _ctx.$slots.icon ? vue.renderSlot(_ctx.$slots, "icon", vue.normalizeProps(vue.mergeProps({ key: 0 }, _ctx.nodeStatus))) : _ctx.icon ? (vue.openBlock(), vue.createBlock(_component_RenderFunction, vue.mergeProps({
          key: 1,
          "render-func": _ctx.icon
        }, _ctx.nodeStatus), null, 16, ["render-func"])) : _ctx.treeNodeIcon ? (vue.openBlock(), vue.createBlock(_component_RenderFunction, vue.mergeProps({
          key: 2,
          "render-func": _ctx.treeNodeIcon,
          node: _ctx.treeNodeData
        }, _ctx.nodeStatus), null, 16, ["render-func", "node"])) : vue.createCommentVNode("v-if", true)
      ], 2)) : vue.createCommentVNode("v-if", true),
      vue.createVNode(_component_m_popconfirm, {
        content: "\u786E\u5B9A\u8981\u5220\u9664\u8BE5\u8282\u70B9\u5417?",
        type: "error",
        position: "right",
        "popup-visible": _ctx.confirmVisible,
        onOk: _ctx.onRemove,
        onCancel: _cache[1] || (_cache[1] = ($event) => _ctx.confirmVisible = false),
        onPopupVisibleChange: _ctx.onConfirmVisibleChange
      }, {
        default: vue.withCtx(() => [
          vue.createElementVNode("span", {
            class: vue.normalizeClass(`${_ctx.prefixCls}-title-text`),
            onDblclick: _cache[0] || (_cache[0] = (...args) => _ctx.openEdit && _ctx.openEdit(...args))
          }, [
            !_ctx.isEdit ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 0 }, [
              _ctx.treeTitle ? (vue.openBlock(), vue.createBlock(_component_RenderFunction, {
                key: 0,
                "render-func": _ctx.treeTitle
              }, null, 8, ["render-func"])) : (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 1 }, [
                vue.createCommentVNode(" \u6807\u9898\uFF0CtreeTitle \u4F18\u5148\u7EA7\u9AD8\u4E8E\u8282\u70B9\u7684 title "),
                vue.renderSlot(_ctx.$slots, "title", {}, () => [
                  vue.createTextVNode(vue.toDisplayString(_ctx.title), 1)
                ])
              ], 2112))
            ], 64)) : (vue.openBlock(), vue.createElementBlock("div", {
              key: 1,
              class: vue.normalizeClass([`${_ctx.prefixCls}-input`])
            }, [
              vue.createVNode(_component_m_input, {
                ref: "inputRef",
                size: "mini",
                "model-value": _ctx.inputValue,
                placeholder: "\u8BF7\u8F93\u5165\u8282\u70B9\u540D\u79F0",
                error: _ctx.isInputError,
                onInput: _ctx.onInput,
                onFocus: _ctx.onInputFocus,
                onPressEnter: _ctx.onInputSave
              }, null, 8, ["model-value", "error", "onInput", "onFocus", "onPressEnter"]),
              vue.createVNode(_component_m_button_group, { size: "mini" }, {
                default: vue.withCtx(() => [
                  vue.createVNode(_component_m_button, {
                    size: "mini",
                    onClick: vue.withModifiers(_ctx.onInputCancel, ["stop"])
                  }, {
                    default: vue.withCtx(() => [
                      vue.createVNode(_component_icon_close)
                    ]),
                    _: 1
                  }, 8, ["onClick"]),
                  vue.createVNode(_component_m_button, {
                    size: "mini",
                    onClick: vue.withModifiers(_ctx.onInputSave, ["stop"])
                  }, {
                    default: vue.withCtx(() => [
                      vue.createVNode(_component_icon_check)
                    ]),
                    _: 1
                  }, 8, ["onClick"])
                ]),
                _: 1
              })
            ], 2)),
            _ctx.draggable ? (vue.openBlock(), vue.createElementBlock("span", {
              key: 2,
              class: vue.normalizeClass([`${_ctx.prefixCls}-icon`, `${_ctx.prefixCls}-drag-icon`])
            }, [
              vue.createCommentVNode(" \u62D6\u62FD\u56FE\u6807 "),
              _ctx.$slots["drag-icon"] ? vue.renderSlot(_ctx.$slots, "drag-icon", vue.normalizeProps(vue.mergeProps({ key: 0 }, _ctx.nodeStatus))) : _ctx.dragIcon ? (vue.openBlock(), vue.createBlock(_component_RenderFunction, vue.mergeProps({
                key: 1,
                "render-func": _ctx.dragIcon
              }, _ctx.nodeStatus), null, 16, ["render-func"])) : _ctx.treeDragIcon ? (vue.openBlock(), vue.createBlock(_component_RenderFunction, vue.mergeProps({
                key: 2,
                "render-func": _ctx.treeDragIcon,
                node: _ctx.treeNodeData
              }, _ctx.nodeStatus), null, 16, ["render-func", "node"])) : (vue.openBlock(), vue.createBlock(_component_IconDragDotVertical, { key: 3 }))
            ], 2)) : vue.createCommentVNode("v-if", true)
          ], 34)
        ]),
        _: 3
      }, 8, ["popup-visible", "onOk", "onPopupVisibleChange"])
    ], 42, _hoisted_1),
    vue.createCommentVNode(" \u989D\u5916 "),
    !_ctx.disabled && (_ctx.append || _ctx.edit || _ctx.remove || _ctx.extra) ? (vue.openBlock(), vue.createElementBlock("span", {
      key: 1,
      class: vue.normalizeClass([`${_ctx.prefixCls}-extra`])
    }, [
      !_ctx.isEdit ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 0 }, [
        _ctx.append ? (vue.openBlock(), vue.createElementBlock("span", {
          key: 0,
          class: vue.normalizeClass([`${_ctx.iconPrefixCls}-hover`, `${_ctx.prefixCls}-ctrl`]),
          onClick: _cache[8] || (_cache[8] = (...args) => _ctx.onAppend && _ctx.onAppend(...args))
        }, [
          vue.createVNode(_component_IconPlus)
        ], 2)) : vue.createCommentVNode("v-if", true),
        _ctx.edit ? (vue.openBlock(), vue.createElementBlock("span", {
          key: 1,
          class: vue.normalizeClass([`${_ctx.iconPrefixCls}-hover`, `${_ctx.prefixCls}-ctrl`]),
          onClick: _cache[9] || (_cache[9] = (...args) => _ctx.openEdit && _ctx.openEdit(...args))
        }, [
          vue.createVNode(_component_icon_pen)
        ], 2)) : vue.createCommentVNode("v-if", true),
        _ctx.remove && !_ctx.isRoot ? (vue.openBlock(), vue.createElementBlock("span", {
          key: 2,
          class: vue.normalizeClass([`${_ctx.iconPrefixCls}-hover`, `${_ctx.prefixCls}-ctrl`]),
          onClick: _cache[10] || (_cache[10] = (...args) => _ctx.onRemoveConfirm && _ctx.onRemoveConfirm(...args))
        }, [
          vue.createVNode(_component_IconDelete)
        ], 2)) : vue.createCommentVNode("v-if", true)
      ], 64)) : vue.createCommentVNode("v-if", true),
      _ctx.extra ? (vue.openBlock(), vue.createBlock(_component_RenderFunction, {
        key: 1,
        "render-func": _ctx.extra
      }, null, 8, ["render-func"])) : vue.createCommentVNode("v-if", true)
    ], 2)) : vue.createCommentVNode("v-if", true)
  ], 2);
}
var BaseTreeNode = /* @__PURE__ */ pluginVue_exportHelper(_sfc_main, [["render", _sfc_render]]);
module.exports = BaseTreeNode;
