"use strict";
var vue = require("vue");
var Event = require("./css-animation/Event.js");
var raf = require("./raf.js");
var globalConfig = require("../_utils/global-config.js");
const findDOMNode = (instance) => {
  var _a;
  let node = ((_a = instance == null ? void 0 : instance.vnode) == null ? void 0 : _a.el) || instance && (instance.$el || instance);
  while (node && !node.tagName) {
    node = node.nextSibling;
  }
  return node;
};
let styleForPesudo;
function isHidden(element) {
  return !element || element.offsetParent === null;
}
function isNotGrey(color) {
  const match = (color || "").match(/rgba?\((\d*), (\d*), (\d*)(, [\.\d]*)?\)/);
  if (match && match[1] && match[2] && match[3]) {
    return !(match[1] === match[2] && match[2] === match[3]);
  }
  return true;
}
var Wave = vue.defineComponent({
  compatConfig: {
    MODE: 3
  },
  name: "Wave",
  props: {
    insertExtraNode: Boolean,
    disabled: Boolean
  },
  setup(props, {
    slots,
    expose
  }) {
    const instance = vue.getCurrentInstance();
    const prefixCls = vue.ref(globalConfig.getPrefixCls());
    let eventIns = null;
    let clickWaveTimeoutId = null;
    let animationStartId = null;
    let animationStart = false;
    let extraNode = null;
    let isUnmounted = false;
    const onTransitionStart = (e) => {
      if (isUnmounted)
        return;
      const node = findDOMNode(instance);
      if (!e || e.target !== node) {
        return;
      }
      if (!animationStart) {
        resetEffect(node);
      }
    };
    const onTransitionEnd = (e) => {
      if (!e || e.animationName !== "fadeEffect") {
        return;
      }
      resetEffect(e.target);
    };
    const getAttributeName = () => {
      const {
        insertExtraNode
      } = props;
      return insertExtraNode ? `${prefixCls.value}-click-animating` : `${prefixCls.value}-click-animating-without-extra-node`;
    };
    const onClick = (node, waveColor) => {
      const {
        insertExtraNode,
        disabled
      } = props;
      if (disabled || !node || isHidden(node) || node.className.indexOf("-leave") >= 0 || node.className.indexOf("switch-type-line") >= 0) {
        return;
      }
      extraNode = document.createElement("div");
      extraNode.className = `${prefixCls.value}-click-animating-node`;
      const attributeName = getAttributeName();
      node.removeAttribute(attributeName);
      node.setAttribute(attributeName, "true");
      styleForPesudo = styleForPesudo || document.createElement("style");
      if (waveColor && waveColor !== "#ffffff" && waveColor !== "rgb(255, 255, 255)" && isNotGrey(waveColor) && !/rgba\(\d*, \d*, \d*, 0\)/.test(waveColor) && waveColor !== "transparent") {
        extraNode.style.borderColor = waveColor;
        styleForPesudo.innerHTML = `
        [${prefixCls.value}-click-animating-without-extra-node='true']::after, .${prefixCls.value}-click-animating-node {
          --antd-wave-shadow-color: ${waveColor};
        }`;
        if (!document.body.contains(styleForPesudo)) {
          document.body.appendChild(styleForPesudo);
        }
      }
      if (insertExtraNode) {
        node.appendChild(extraNode);
      }
      Event.addStartEventListener(node, onTransitionStart);
      Event.addEndEventListener(node, onTransitionEnd);
    };
    const resetEffect = (node) => {
      if (!node || node === extraNode || !(node instanceof Element)) {
        return;
      }
      const {
        insertExtraNode
      } = props;
      const attributeName = getAttributeName();
      node.setAttribute(attributeName, "false");
      if (styleForPesudo) {
        styleForPesudo.innerHTML = "";
      }
      if (insertExtraNode && extraNode && node.contains(extraNode)) {
        node.removeChild(extraNode);
      }
      Event.removeStartEventListener(node, onTransitionStart);
      Event.removeEndEventListener(node, onTransitionEnd);
    };
    const bindAnimationEvent = (node) => {
      if (!node || !node.getAttribute || node.getAttribute("disabled") || node.className.indexOf("disabled") >= 0) {
        return;
      }
      const newClick = (e) => {
        var _a;
        if (e.target.tagName === "INPUT" || isHidden(e.target)) {
          return;
        }
        resetEffect(node);
        let waveColor = getComputedStyle(node).getPropertyValue("background-color") === "rgba(0, 0, 0, 0)" ? getComputedStyle(node).getPropertyValue("color") : getComputedStyle(node).getPropertyValue("background-color");
        if (waveColor === "rgb(201, 205, 212)" && node.getAttribute("role") === "switch" && ((_a = node.getAttribute("class")) == null ? void 0 : _a.indexOf("mo-switch-type-line")) === -1) {
          waveColor = "rgba(0, 0, 0, 0.85)";
        }
        clickWaveTimeoutId = setTimeout(() => onClick(node, waveColor), 0);
        raf.cancel(animationStartId);
        animationStart = true;
        animationStartId = raf(() => {
          animationStart = false;
        }, 10);
      };
      node.addEventListener("click", newClick, true);
      return {
        cancel: () => {
          node.removeEventListener("click", newClick, true);
        }
      };
    };
    vue.onMounted(() => {
      vue.nextTick(() => {
        const node = findDOMNode(instance);
        if (node.nodeType !== 1) {
          return;
        }
        eventIns = bindAnimationEvent(node);
      });
    });
    vue.onBeforeUnmount(() => {
      if (eventIns) {
        eventIns.cancel();
      }
      clearTimeout(clickWaveTimeoutId);
      isUnmounted = true;
    });
    return () => {
      var _a;
      return (_a = slots.default) == null ? void 0 : _a.call(slots)[0];
    };
  }
});
module.exports = Wave;
